/*
A copyright statement is attached to every file and product created for the
project.  It takes the form of the copyright statement for this 
document:

The project provides a modern way to design and knit garments
using domestic and semi-professional knitting machines.  This document
describes the LockController hardware.

Copyright (C) 2020 Owen Mace and Odile Lambert

This document is free information: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
*/
//Pointer for E6000 knitting machinesś front lock
//Version 2 - 11 July 2020  Move tab at front towards the lock 
// so that it is out of the way of strippers

$fs = 0.1; //Sets the number of fragments used in a circle

FrontLockJoinerWidth = 21;
Zmax      = 20;   //Height at the back
CaseAngle = asin( 4.5 / 25);
//echo( CaseAngle);

Xmax      = 29;   //Width
Ymax      = 59;   //Length
Thick     =  2;   //Wall thickness
Xjoin     = 21;   //Width of metal on front lock
TabDia    = 5.5;  //Diameter of tab
TabHeight = 1;    //Height of circular tab
//Xmax  = ( FrontLockJoinerWidth + 1.5 + Thick * 2) / cos( CaseAngle); //Width
Zfrt      = 15;   //Height at the front
HoleDia   = 13.5; //Diameter of Hole on top
PegZ      = 2;    //Peg size in Z
Tolerance = 0.2;  //Manufacturing tolerance

rotate([ 0, 180, 0])
{

SlotCentreLineX = Xmax / 2 - HoleDia / 2 - 5;
//Playing with text
translate([ Xmax / 2, -27, 0]) rotate([ 90, 0, 90])
linear_extrude( height = 0.5)
  text( "E6000 Pointer V2", size = 5);

difference()
{
  //Dimensions of hole at front
  Xa = 21; //Width of hole
  Za = 13; //Height of hole
  Case( Xmax, Ymax, Zmax);
  //Remove centre
  translate([ Xmax / 2 - Thick - Xjoin / 2, 0, -Thick])
    cube([ Xjoin, Ymax + 1, Zmax], center = true);
  //Remove the slot on the top
  translate([ SlotCentreLineX, -Ymax / 2 + 26.5, 0])
  rotate([ 0, 0, 90])
    Slot( 39, HoleDia, Zmax * 2);
  //Remove below the bar at the front
  translate([ 0, Ymax / 2, -Zmax / 2])
    cube([ Xmax + 2, 25, 5], center = true);
  //Remove the bottom of the sides Front
  SlotLength  = 23;
  SlotWidth   = 10;
  SlotYOffset = 13;
  translate([  Xmax / 2, Ymax / 2 - SlotYOffset - 10, Zmax / 2 - 20])
  rotate([ 90, 0, 90])
    Slot( SlotLength + 4, SlotWidth, 5);
  translate([ -Xmax / 2 + 2, Ymax / 2 - SlotYOffset - 4.7, Zmax / 2 - 20])
  rotate([ 90, 0, 90])
    Slot( SlotLength - 8, SlotWidth, 10);
  //Chamfer the bottom front
  translate([ -Xmax / 2, Ymax / 2 - 3, -Zmax / 2 - 3]) rotate([ 45, 0, 0])
    cube([ Xmax + 10, 11, 6]);
  //Remove the bottom of the sides Back
  translate([  Xmax / 2, Ymax / 2 - SlotYOffset - 30, Zmax / 2 - 22])
  rotate([ 90, 0, 90])
    Slot( SlotLength, SlotWidth, 5);
  translate([ -Xmax / 2, Ymax / 2 - SlotYOffset - 30, Zmax / 2 - 22])
  rotate([ 90, 0, 90])
    Slot( SlotLength, SlotWidth, 15);
  translate([ -Xmax / 2 - 5,
              -Ymax / 2 - ( Zmax - PegZ - Thick * 2) * tan( CaseAngle) / 2,
              -Zmax / 2 + PegZ - 0.5])
  rotate([ CaseAngle, 0, 0])
    cube([ Xmax + 10, Thick * 2, Zmax]); 
}
//Add tabs at the front
  translate([ Xmax / 2 - Thick, Ymax / 2 - 8, -Zmax / 2 + 3.5])
    cube([ Thick + 2, 4, 2], center = true);
  translate([ -Xmax / 2 - Thick + 8, Ymax / 2 - 8, -Zmax / 2 + 3.5])
    cube([ Thick + 2, 4, 2], center = true);
//Add the tab
TabAdjustment = 6;
translate([ SlotCentreLineX,
            Ymax / 2 - Zmax * tan( CaseAngle) - TabAdjustment,
            Zmax / 2 - Thick - TabHeight])
  cylinder( TabHeight, d = TabDia);
// Add the Pointer
Ymove = Ymax / 2 - 25 - 7;
translate([ -Xmax / 2 + Thick / 4, Ymove, Zmax / 2 - 5])
rotate([ 0, 90, 0])
  Pointer();

//Add the cable holders
D = 6; //Diameter of cable
L = 25; //Length of cable holder
translate([ -Xmax / 2 - 4.5, Ymove - 9, Zmax / 2 - 15])
  difference()
  {
    cube([ 8, L, 10]);
    //Remove the hole for the cable
    translate([ D - 4, L / 2, 5])
    rotate([ 90, 0, 0])
      cylinder( L + 5, d = D, center = true);
    //Remove the slots between the cable holders
    translate([ Xmax / 2 - 10 - Thick, 7, 5])
    rotate([ 0, CaseAngle, 0])
      cube([ 10, 2, 15], center = true);
    translate([ Xmax / 2 - 10 - Thick, 17, 5])
    rotate([ 0, CaseAngle, 0])
      cube([ 10, 2, 15], center = true);
    //Make the cable holders ome sided
    Xmov = Xmax / 2 - 10.4 - Thick;
    translate([ Xmov, Ymax / 2 - 8, 8])
      cube([ 6, 10, 6], center = true);
    translate([ Xmov, Ymax / 2 - 28, 8])
      cube([ 6, 10, 6], center = true);
    translate([ Xmov, Ymax / 2 - 17, 1])
      cube([ 6, 10, 6], center = true);
    //Break the sharp edges on cable holder
    translate([ -1, -Ymove + 10, -Zmax / 2 + 15])
      cube([ 6, L + 4, D - Tolerance * 2], center = true);
  }
}

module Pointer()
{
  //Pointer data
  L = 29; //Pointer length
  W = 7;  //Pointer width
  C = W / sqrt( 2);
  difference()
  {
    cube([ L, W, Thick]);
    translate([ L,  W / 2, -Thick]) rotate([ 0, 0, 45])
      cube([ C, C, Thick * 3]);
    translate([ L, -W / 2, -Thick]) rotate([ 0, 0, 45])
      cube([ C, C, Thick * 3]);
  }
}
module Slot( Length, Width, Height)
{
  cube([ Length - Width, Width, Height], center = true);
  translate([ -(Length - Width) / 2, 0, 0])
    cylinder( Height, d = Width, center = true);
  translate([  (Length - Width) / 2, 0, 0])
    cylinder( Height, d = Width, center = true);
}
module Case( Xdim, Ydim, Zdim)
{
  difference()
  {
    cube([ Xdim, Ydim, Zdim], center = true);
    //Remove sloping left side
    translate([ -Xdim / 2, 0, 0])
    rotate([ 0, CaseAngle, 0])
      cube([ Xdim / 6, Ydim + 5, Zdim + 5], center = true);
    //Remove sloping far end
    Yt = 5;
    translate([ 0, Ymax / 2 + Yt / 2 - Zmax / 2 * sin( 6), 3])
    rotate([ CaseAngle, 0, 0])
      cube([ Xmax + 1, Yt, Zmax], center = true);
  }
}
//These polyhedrons don work and I don´t know why
//Trangular polyhedron data
T2 = Xmax+ 10;
H  = Zmax - 2;
Y1 = (Zmax - 2) * tan( CaseAngle);
TriPoints = [
  [ 0, 0,  0], //0
  [ 3, 0,  0], //1
  [ 0, H,  0], //2
  [ 0, 0, T2], //3
  [ 3, 0, T2], //4
  [ 0, H, T2]];//5
TriFaces  = [
  [ 0, 1, 2],    //Bottom
  [ 0, 3, 4, 1], //A
  [ 1, 4, 5, 2], //B
  [ 3, 0, 2, 5], //C
  [ 3, 5, 4]];   //Top
//Pointer data
L1 = 27; //Pointer length
L2 = L1 + 2; //length over arrow
W  = 7;  //Pointer width
T  = Thick;
PointerPoints = [
  [  0,  0,  0], //0
  [ L1,  0,  0], //1
  [ L2, W/2, 0], //2
  [ L1, W,   0], //3
  [  0, W,   0], //4
  [  0,  0,  T], //5
  [ L1,  0,  T], //6
  [ L2, W/2, T], //7
  [ L1, W,   T], //8
  [  0, W,   T]];//9
PointerFaces = [
  [ 0, 1, 6, 5], //A
  [ 1, 2, 7, 6], //B - Arrow
  [ 2, 3, 8, 7], //C - Arrow
  [ 3, 4, 9, 8], //D
  [ 0, 5, 9, 4], //E
  [ 5, 6, 7, 8, 9], //top
  [ 0, 4, 3, 2, 1]]; //Bottom
  
